#
# spec file for package python-scapy
#
# Copyright (c) 2020 Packman Team <packman@links2linux.de>
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#

%if 0%{suse_version} > 1500
%bcond_without python_sphinx2
%else
%bcond_with    python_sphinx2
%endif

Name:           python-scapy
Version:        2.4.4
Release:        150400.1.pm.2
Summary:        Interactive Packet Manipulation Tool
License:        GPL-2.0-or-later
URL:            https://scapy.net
Source0:        https://github.com/secdev/scapy/archive/v%{version}.tar.gz#/scapy-%{version}.tar.gz
Patch1:         python-scapy-no-buildtime.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with python_sphinx2}
BuildRequires:  python3-Sphinx
%endif
BuildArch:      noarch
%python_subpackages


%description
Scapy is a powerful interactive packet manipulation tool, packet generator,
network scanner, network discovery tool, and packet sniffer. It provides
classes to interactively create packets or sets of packets, manipulate them,
send them over the wire, sniff other packets from the wire, match answers and
replies, and more. Interaction is provided by the Python interpreter, so Python
programming structures can be used (such as variables, loops, and functions).
Report modules are possible and easy to make. It is intended to do about the
same things as ttlscan, nmap, hping, queso, p0f, xprobe, arping, arp-sk,
arpspoof, firewalk, irpas, tethereal, tcpdump, etc.

%prep
%autosetup -p1 -n scapy-%{version}

%build
# remove shebang
find scapy -type f -name "*.py" -exec sed -i '/^#!/d' {} \;

%python_build
%if %{with python_sphinx2}
%make_build -C doc/scapy html
rm -fv doc/scapy/_build/html/.buildinfo doc/scapy/_build/html/_static/_dummy
%endif

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%license LICENSE
%doc README
%if %{with python_sphinx2}
%doc doc/scapy/_build/html
%endif
%python3_only %{_bindir}/UTscapy
%python3_only %{_bindir}/scapy
%{_mandir}/man1/scapy.1%{?ext_man}
%{python_sitelib}/*

%changelog
* Wed Dec 30 2020 olaf@aepfle.de
- Update to version 2.4.4
* Tue Apr 21 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 2.4.3
  * Core
    + 364 commits since v2.4.2
    + latency improvements
    + sniff() can be used to test BPF fiters on pcap files
    + more unit tests and Python3 compatibility
    + asynchronous sniffing
    + UTScapy vim syntax highlighting
    + drop distutils for setuptools
    + Console / IPython integration improvements
  Layers
  * New
    + HTTP (from the deprecated scapy-http module), TLS 1.3, ATA
    over Ethernet, OVD, IEC 60870-5-104, enip
  * Improved
    + NetflowV9, ISOTP, Zigbee, RTR, BLE, PPI, DNS, LLDP
    + Bluetooth/BTLE rework
    + PPI / 802.11 improvements
  version 2.4.2:
  * Gabriel Potter is officially part of the Scapy maintainers
    team
  * PEP08 compliance (see #1277)
  * Speed improvements (see #642)
  * Core
    + 253 merged pull requests since v2.4.0
    + Python 3.7 support
    + Enhanced Windows support
    + unit testing is now 100%% tox based
  Layers
  * Many automotive related layers added (ISO-TP...)
  * New
    + EtherCat
    + OPCDA
    + SOCKS
    + USBpcap
    + RPKI
  * Improved
    + MACsec, MQTT, MPLS, DNS, ARP, Dot15d4, Zigbee,
    Bluetooth4LE, RadioTap
    + Enhanced monitor mode support
  * Other
    + addresses a v2.4.0 vulnerability
  version 2.4.0:
  * Python3 support
  * 85%% code coverage
  * Core
    + Pcap/PcapNg improvements
    + enhanced Windows support
    + Krack AP module
    + iPython support
    + automatically tested
  * Layers
    + TLS (including TLS1.3), X.509
  * New
    + HTTP/2, EAP-TTLS, TACACS, MQTT
  * Improved
    + IPv6, SCTP, NTP, PPTP, CDP, BGP, ISIS
- Use singlespec syntax
- Refreshed python-scapy-no-buildtime.patch
- Spec cleanup
* Fri Apr 11 2014 p.drouand@gmail.com
- Specfile cleanup
* Tue Nov 20 2012 p.drouand@gmail.com  
- Initial release
